/hg/gfx-test: Updates.

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Thu Aug 6 07:59:53 UTC 2015


changeset bfdcbd1179ce in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=bfdcbd1179ce
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Thu Aug 06 10:02:33 2015 +0200

	Updates.


diffstat:

 ChangeLog                                          |    5 +
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  106 ++++++++++----------
 2 files changed, 58 insertions(+), 53 deletions(-)

diffs (184 lines):

diff -r 717cdb23cc52 -r bfdcbd1179ce ChangeLog
--- a/ChangeLog	Wed Aug 05 12:32:27 2015 +0200
+++ b/ChangeLog	Thu Aug 06 10:02:33 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-06  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updates.
+
 2015-08-05  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
diff -r 717cdb23cc52 -r bfdcbd1179ce src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Aug 05 12:32:27 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Aug 06 10:02:33 2015 +0200
@@ -9481,7 +9481,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9490,13 +9490,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9505,13 +9505,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9520,13 +9520,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9535,13 +9535,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9550,13 +9550,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9565,13 +9565,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9580,13 +9580,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9595,9 +9595,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.yellow);
     }
 
     /**
@@ -9481,7 +9481,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.white.
      *


More information about the distro-pkg-dev mailing list